==> nextcloud-app-mail-5.5.10-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/nn_NO.js <==
OC.L10N.register(
    "mail",
    {
    "Important" : "Viktig",
    "Work" : "Arbeid",
    "Personal" : "Personleg",
    "Mail" : "Post",
    "Save" : "Lagre",
    "Connect" : "Kopla til",
    "Name" : "Namn",
    "Password" : "Passord",
    "None" : "Ingen",
    "Signature" : "Signatur",
    "Cancel" : "Avbryt",
    "Accounts" : "Accounts",
    "General" : "Generelt",
    "Keyboard shortcuts" : "Tastatursnarvegar",
    "Delete" : "Ta bort",
    "Search" : "Search",
    "Send" : "Send",
    "Refresh" : "Last inn på nytt",
    "Ok" : "Greitt",
    "Choose" : "Vel",
    "Favorite" : "Favoritt",
    "Back" : "Tilbake",
    "Attendees" : "Deltakarar",
    "Description" : "Skildring",
    "Create" : "Lag",
    "Select" : "Vel",
    "Comment" : "Kommentér",
    "Remove" : "Fjern",
    "Today" : "I dag",
    "Yesterday" : "I går",
    "Other" : "Anna",
    "Move" : "Move",
    "Folder name" : "Katalognavn",
    "Saving" : "Lagrar",
    "Rename" : "Endra namn",
    "Reply" : "Svare",
    "Retry" : "Forsøk att",
    "Add" : "Legg til",
    "Close" : "Lat att",
    "Date" : "Dato",
    "Tags" : "Emneord",
    "Recipient" : "Mottakar",
    "Help" : "Hjelp",
    "contains" : "inneheld",
    "Actions" : "Handlingar",
    "delete" : "slett",
    "Edit" : "Rediger",
    "Client ID" : "Klient-ID",
    "User" : "Bruker",
    "Host" : "Tenar",
    "Port" : "Port",
    "Certificate" : "Sertifikat",
    "Guest" : "Gjest",
    "Group" : "Gruppe",
    "Shared" : "Delt",
    "Shares" : "Delingar",
    "All" : "Alle",
    "Favorites" : "Favorit",
    "Sent" : "Sendt",
    "Message sent" : "Melding sendt"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-mail-5.5.11-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/nn_NO.js <==
OC.L10N.register(
    "mail",
    {
    "Important" : "Viktig",
    "Work" : "Arbeid",
    "Personal" : "Personleg",
    "Mail" : "Post",
    "Save" : "Lagre",
    "Connect" : "Kopla til",
    "Name" : "Namn",
    "Password" : "Passord",
    "None" : "Ingen",
    "Signature" : "Signatur",
    "Cancel" : "Avbryt",
    "General" : "Generelt",
    "Appearance" : "Utsjånad",
    "Newest first" : "Nyaste fyrst",
    "Oldest first" : "Eldste fyrst",
    "Keyboard shortcuts" : "Tastatursnarvegar",
    "Delete" : "Ta bort",
    "Search" : "Search",
    "Send" : "Send",
    "Refresh" : "Last inn på nytt",
    "Ok" : "Greitt",
    "Choose" : "Vel",
    "Favorite" : "Favoritt",
    "Back" : "Tilbake",
    "Attendees" : "Deltakarar",
    "Description" : "Skildring",
    "Create" : "Lag",
    "Select" : "Vel",
    "Comment" : "Kommentér",
    "Remove" : "Fjern",
    "Today" : "I dag",
    "Yesterday" : "I går",
    "Other" : "Anna",
    "Move" : "Move",
    "Folder name" : "Katalognavn",
    "Saving" : "Lagrar",
    "Rename" : "Endra namn",
    "Reply" : "Svare",
    "Retry" : "Forsøk att",
    "Add" : "Legg til",
    "Close" : "Lat att",
    "Date" : "Dato",
    "Tags" : "Emneord",
    "Recipient" : "Mottakar",
    "Help" : "Hjelp",
    "contains" : "inneheld",
    "Actions" : "Handlingar",
    "delete" : "slett",
    "Edit" : "Rediger",
    "Client ID" : "Klient-ID",
    "User" : "Bruker",
    "Host" : "Tenar",
    "Port" : "Port",
    "Certificate" : "Sertifikat",
    "Guest" : "Gjest",
    "Group" : "Gruppe",
    "Shared" : "Delt",
    "Shares" : "Delingar",
    "All" : "Alle",
    "Favorites" : "Favorit",
    "Sent" : "Sendt",
    "Message sent" : "Melding sendt",
    "Accounts" : "Accounts"
},
"nplurals=2; plural=(n != 1);");
